summaryrefslogtreecommitdiff
path: root/intrpvar.h
diff options
context:
space:
mode:
authorKarl Williamson <public@khwilliamson.com>2011-11-09 15:46:33 -0700
committerKarl Williamson <public@khwilliamson.com>2011-11-09 16:24:05 -0700
commit45d91b83242e04182e545e492a98ea94c6f0b3d6 (patch)
tree27b318276c5abe4696a9fee7f38decdffd862a8d /intrpvar.h
parent3e3c678a0e016dee50e52180a5e5a14b351a4ebd (diff)
downloadperl-45d91b83242e04182e545e492a98ea94c6f0b3d6.tar.gz
intrpvar.h: Increase size of variable that stores UTF8 bytes
A Perl utf8 string can occupy 13 bytes. This only accepted up to 11, causing a swash assertion failure for very large code points matching Unicode properties.
Diffstat (limited to 'intrpvar.h')
-rw-r--r--intrpvar.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/intrpvar.h b/intrpvar.h
index 66daab2916..c8c08872cb 100644
--- a/intrpvar.h
+++ b/intrpvar.h
@@ -596,8 +596,8 @@ PERLVAR(I, utf8_tofold, SV *)
PERLVAR(I, last_swash_hv, HV *)
PERLVAR(I, last_swash_tmps, U8 *)
PERLVAR(I, last_swash_slen, STRLEN)
-PERLVARA(I, last_swash_key,10, U8)
-PERLVAR(I, last_swash_klen, U8) /* Only needs to store 0-10 */
+PERLVARA(I, last_swash_key,12, U8)
+PERLVAR(I, last_swash_klen, U8) /* Only needs to store 0-12 */
#ifdef FCRYPT
PERLVARI(I, cryptseen, bool, FALSE) /* has fast crypt() been initialized? */